@@ -51,7 +51,6 @@ namespace Tomboy
 
 			if (menu_verbs == null) {
 				menu_verbs = new BonoboUIVerb [] {
-					new BonoboUIVerb ("Plugins", ShowPluginsVerb),
 					new BonoboUIVerb ("Props", ShowPreferencesVerb),
 					new BonoboUIVerb ("Help", ShowHelpVerb),
 					new BonoboUIVerb ("About", ShowAboutVerb)
@@ -81,22 +80,19 @@ namespace Tomboy
 
 		void ShowPreferencesVerb ()
 		{
-			tray.ShowPreferences ();
-		}
-
-		void ShowPluginsVerb ()
-		{
-			manager.PluginManager.ShowPluginsDirectory ();
+			Tomboy.ActionManager ["ShowPreferencesAction"].Activate ();
 		}
 
 		void ShowHelpVerb ()
 		{
-			GuiUtils.ShowHelp("tomboy.xml", null, Screen, null);
+			// Don't use the ActionManager in this case because
+			// the handler won't know about the Screen.
+			GuiUtils.ShowHelp ("tomboy.xml", null, Screen, null);
 		}
 
 		void ShowAboutVerb ()
 		{
-			tray.ShowAbout ();
+			Tomboy.ActionManager ["ShowAboutAction"].Activate ();
 		}
 
 		protected override void OnChangeBackground (PanelAppletBackgroundType type, 
@@ -182,13 +178,6 @@ namespace Tomboy
 
 			Gtk.ImageMenuItem item;
 
-			item = new Gtk.ImageMenuItem (Catalog.GetString ("_Open Plugins Folder"));
-			item.Image = new Gtk.Image (Gtk.Stock.Execute, Gtk.IconSize.Menu);
-			item.Activated += ShowPlugins;
-			menu.Append (item);
-
-			menu.Append (new Gtk.SeparatorMenuItem ());
-
 			item = new Gtk.ImageMenuItem (Catalog.GetString ("_Preferences"));
 			item.Image = new Gtk.Image (Gtk.Stock.Preferences, Gtk.IconSize.Menu);
 			item.Activated += ShowPreferences;
@@ -217,28 +206,28 @@ namespace Tomboy
 
 		void ShowPreferences (object sender, EventArgs args)
 		{
-			tray.ShowPreferences ();
-		}
-
-		void ShowPlugins (object sender, EventArgs args)
-		{
-			manager.PluginManager.ShowPluginsDirectory ();
+			Tomboy.ActionManager ["ShowPreferencesAction"].Activate ();
 		}
 
 		void ShowHelpContents (object sender, EventArgs args)
 		{
-			GuiUtils.ShowHelp("tomboy.xml", null, Screen, null);
+			Tomboy.ActionManager ["ShowHelpAction"].Activate ();
 		}
 
 		void ShowAbout (object sender, EventArgs args)
 		{
-			tray.ShowAbout ();
+			Tomboy.ActionManager ["ShowAboutAction"].Activate ();
 		}
 
 		void Quit (object sender, EventArgs args)
 		{
-			Logger.Log ("Quitting Tomboy.  Ciao!");
-			Tomboy.Exit (0);
+			Tomboy.ActionManager ["QuitTomboyAction"].Activate ();
+		}
+		
+		public TomboyTray TomboyTray
+		{
+			get { return tray; }
 		}
 	}
 }
+
