@@ -1,8 +1,11 @@
 
 using System;
 using System.IO;
+using System.Xml;
 using Mono.Unix;
 
+using Tomboy.Sync;
+
 namespace Tomboy 
 {
 	public class Tomboy : Application
@@ -12,6 +15,7 @@ namespace Tomboy
 		static bool tray_icon_showing = false;
 		static bool is_panel_applet = false;
 		static PreferencesDialog prefs_dlg;
+		static SyncDialog sync_dlg;
 #if ENABLE_DBUS
 		static RemoteControl remote_control;
 #endif
@@ -33,12 +37,14 @@ namespace Tomboy
 
 			Initialize ("tomboy", "Tomboy", "tomboy", args);
 
-			PluginManager.CheckPluginUnloading = cmd_line.CheckPluginUnloading;
+//			PluginManager.CheckPluginUnloading = cmd_line.CheckPluginUnloading;
 
 			// Create the default note manager instance.
 			string note_path = GetNotePath (cmd_line.NotePath);
 			manager = new NoteManager (note_path);
 
+			SyncManager.Initialize ();
+
 			// Register the manager to handle remote requests.
 			RegisterRemoteControl (manager);
 			
@@ -50,6 +56,12 @@ namespace Tomboy
 			}
 #endif
 			ActionManager am = Tomboy.ActionManager;
+			
+			ApplicationAddin [] addins =
+				manager.AddinManager.GetApplicationAddins ();
+			foreach (ApplicationAddin addin in addins) {
+				addin.Initialize ();
+			}
 
 			if (cmd_line.UsePanelApplet) {
 				tray_icon_showing = true;
@@ -164,6 +176,7 @@ namespace Tomboy
 			am ["ShowAboutAction"].Activated += OnShowAboutAction;
 			am ["TrayNewNoteAction"].Activated += OnNewNoteAction;
 			am ["ShowSearchAllNotesAction"].Activated += OpenSearchAll;
+			am ["NoteSynchronizationAction"].Activated += OpenNoteSyncWindow;
 		}
 		
 		static void OnNewNoteAction (object sender, EventArgs args)
@@ -185,7 +198,23 @@ namespace Tomboy
 			}
 		}
 		
-		static void OnQuitTomboyAction (object sender, EventArgs args)
+		static void OpenNoteSyncWindow (object sender, EventArgs args)
+		{
+			if (sync_dlg == null) {
+				sync_dlg = new SyncDialog ();
+				sync_dlg.Response += OnSyncDialogResponse;
+			}
+			
+			sync_dlg.Present ();
+		}
+		
+		static void OnSyncDialogResponse (object sender, Gtk.ResponseArgs args)
+		{
+			((Gtk.Widget) sender).Destroy ();
+			sync_dlg = null;
+		}
+	                 
+	    static void OnQuitTomboyAction (object sender, EventArgs args)
 		{
 			if (Tomboy.IsPanelApplet)
 				return; // Ignore the quit action
@@ -197,7 +226,7 @@ namespace Tomboy
 		static void OnShowPreferencesAction (object sender, EventArgs args)
 		{
 			if (prefs_dlg == null) {
-				prefs_dlg = new PreferencesDialog (manager.PluginManager);
+				prefs_dlg = new PreferencesDialog (manager.AddinManager);
 				prefs_dlg.Response += OnPreferencesResponse;
 			}
 			prefs_dlg.Present ();
@@ -279,6 +308,11 @@ namespace Tomboy
 		{
 			get { return tray_icon.TomboyTray; }
 		}
+		
+		public static SyncDialog SyncDialog
+		{
+			get { return sync_dlg; }
+		}
 	}
 
 	public class TomboyCommandLine
@@ -289,11 +323,12 @@ namespace Tomboy
 		bool open_start_here;
 		string open_note_uri;
 		string open_note_name;
+		string open_external_note_path;
 		string highlight_search;
 		string note_path;
 		string search_text;
 		bool open_search;
-		bool check_plugin_unloading;
+//		bool check_plugin_unloading;
 
 		public TomboyCommandLine (string [] args)
 		{
@@ -312,7 +347,8 @@ namespace Tomboy
 						open_note_name != null ||
 						open_note_uri != null || 
 						open_search ||
-						open_start_here;
+						open_start_here ||
+						open_external_note_path != null;
 			}
 		}
 
@@ -321,10 +357,10 @@ namespace Tomboy
 			get { return note_path; }
 		}
 
-		public bool CheckPluginUnloading
-		{
-			get { return check_plugin_unloading; }
-		}
+//		public bool CheckPluginUnloading
+//		{
+//			get { return check_plugin_unloading; }
+//		}
 
 		public static void PrintAbout () 
 		{
@@ -363,10 +399,11 @@ namespace Tomboy
 					"in the opened note.\n");
 #endif
 
-			usage +=
-				Catalog.GetString (
-					"  --check-plugin-unloading\tCheck if plugins are " +
-					"unloaded properly.\n");
+// TODO: Restore this functionality with addins
+//			usage +=
+//				Catalog.GetString (
+//					"  --check-plugin-unloading\tCheck if plugins are " +
+//					"unloaded properly.\n");
 
 #if !ENABLE_DBUS
 			usage += Catalog.GetString ("D-BUS remote control disabled.\n");
@@ -414,7 +451,10 @@ namespace Tomboy
 					// If the argument looks like a Uri, treat it like a Uri.
 					if (args [idx].StartsWith ("note://tomboy/"))
 						open_note_uri = args [idx];
-					else
+					else if (File.Exists (args [idx])) {
+						// This is potentially a note file
+						open_external_note_path = args [idx];
+					} else
 						open_note_name = args [idx];
 
 					break;
@@ -490,9 +530,9 @@ namespace Tomboy
 					open_search = true;
 					break;
 
-				case "--check-plugin-unloading":
-					check_plugin_unloading = true;
-					break;
+//				case "--check-plugin-unloading":
+//					check_plugin_unloading = true;
+//					break;
 
 				case "--version":
 					PrintAbout ();
@@ -559,6 +599,52 @@ namespace Tomboy
 					remote.DisplayNote (open_note_uri);
 			}
 			
+			if (open_external_note_path != null) {
+				string note_id = Path.GetFileNameWithoutExtension (open_external_note_path);
+				if (note_id != null && note_id != string.Empty) {
+					// Attempt to load the note, assuming it might already
+					// be part of our notes list.
+					if (remote.DisplayNote (
+							string.Format ("note://tomboy/{0}", note_id)) == false) {
+
+						StreamReader sr = File.OpenText (open_external_note_path);
+						if (sr != null) {
+							string noteTitle = null;
+							string noteXml = sr.ReadToEnd ();
+							
+							// Make sure noteXml is parseable
+							XmlDocument xmlDoc = new XmlDocument ();
+							try {
+								xmlDoc.LoadXml (noteXml);
+							} catch {
+								noteXml = null;
+							}
+							
+							if (noteXml != null) {
+								noteTitle = NoteArchiver.Instance.GetTitleFromNoteXml (noteXml);
+								if (noteTitle != null) {
+									// Check for conflicting titles
+									string baseTitle = (string)noteTitle.Clone ();
+									for (int i = 1; remote.FindNote (noteTitle) != string.Empty; i++)
+										noteTitle = baseTitle + " (" + i.ToString() + ")";
+									
+									string note_uri = remote.CreateNamedNote (noteTitle);
+									
+									// Update title in the note XML
+									noteXml = NoteArchiver.Instance.GetRenamedNoteXml (noteXml, baseTitle, noteTitle);
+
+									if (note_uri != null) {
+										// Load in the XML contents of the note file
+										if (remote.SetNoteCompleteXml (note_uri, noteXml))
+											remote.DisplayNote (note_uri);
+									}
+								}
+							}
+						}
+					}
+				}
+			}
+			
 			if (open_search) {
 				if (search_text != null)
 					remote.DisplaySearchWithText (search_text);
